==> edge-login-ui-rn-0.9.23.tgz: package/lib/components/themed/EdgeText.js <==
// copied EdgeText component from 'edge-react-gui'
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { Text } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { withTheme } from '../services/ThemeContext';
class EdgeTextComponent extends React.PureComponent {
    render() {
        const _a = this.props, { children, style, theme, disableFontScaling = false } = _a, props = __rest(_a, ["children", "style", "theme", "disableFontScaling"]);
        const { text } = getStyles(theme);
        let numberOfLines = typeof this.props.numberOfLines === 'number'
            ? this.props.numberOfLines
            : 1;
        if (typeof children === 'string' && children.includes('\n')) {
            numberOfLines = numberOfLines + (children.match(/\n/g) || []).length;
        }
        return (React.createElement(Text, Object.assign({ style: [text, style], numberOfLines: numberOfLines, allowFontScaling: !disableFontScaling, adjustsFontSizeToFit: !disableFontScaling, minimumFontScale: 0.65 }, props), children));
    }
}
const getStyles = cacheStyles((theme) => ({
    text: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1)
    }
}));
export const EdgeText = withTheme(EdgeTextComponent);

==> edge-login-ui-rn-0.10.11.tgz: package/lib/components/themed/EdgeText.js <==
// copied EdgeText component from 'edge-react-gui'
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { Text } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { withTheme } from '../services/ThemeContext';
class EdgeTextComponent extends React.PureComponent {
    render() {
        const _a = this.props, { children, style, theme, disableFontScaling = false } = _a, props = __rest(_a, ["children", "style", "theme", "disableFontScaling"]);
        const { text } = getStyles(theme);
        let numberOfLines = typeof this.props.numberOfLines === 'number'
            ? this.props.numberOfLines
            : 1;
        if (typeof children === 'string' && children.includes('\n')) {
            numberOfLines = numberOfLines + (children.match(/\n/g) || []).length;
        }
        return (React.createElement(Text, Object.assign({ style: [text, style], numberOfLines: numberOfLines, adjustsFontSizeToFit: !disableFontScaling, minimumFontScale: 0.65 }, props), children));
    }
}
const getStyles = cacheStyles((theme) => ({
    text: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1)
    }
}));
export const EdgeText = withTheme(EdgeTextComponent);
